"""


Wm Job Type Items
^^^^^^^^^^^^^^^^^

:RENDER:          
  Regular rendering.

:RENDER_PREVIEW:  
  Rendering previews.

:OBJECT_BAKE:     
  Object Baking.

:COMPOSITE:       
  Compositing.

:SHADER_COMPILATION:
  Shader compilation.

.. _rna-enum-wm-job-type-items:

"""

import typing
