"""


Dt Method Edge Items
^^^^^^^^^^^^^^^^^^^^

:TOPOLOGY:        
  Topology.

  Copy from identical topology meshes.

:VERT_NEAREST:    
  Nearest Vertices.

  Copy from most similar edge (edge which vertices are the closest of destination edge's ones).

:NEAREST:         
  Nearest Edge.

  Copy from closest edge (using midpoints).

:POLY_NEAREST:    
  Nearest Face Edge.

  Copy from closest edge of closest face (using midpoints).

:EDGEINTERP_VNORPROJ:
  Projected Edge Interpolated.

  Interpolate all source edges hit by the projection of destination one along its own normal (from vertices).

.. _rna-enum-dt-method-edge-items:

"""

import typing
