"""


Views Format Items
^^^^^^^^^^^^^^^^^^

:INDIVIDUAL:      
  Individual.

  Individual files for each view with the prefix as defined by the scene views.

:STEREO_3D:       
  Stereo 3D.

  Single file with an encoded stereo pair.

.. _rna-enum-views-format-items:

"""

import typing
