"""


Exr Codec Items
^^^^^^^^^^^^^^^

:NONE:            
  None.

:PXR24:           
  Pxr24 (lossy).

:ZIP:             
  ZIP (lossless).

:PIZ:             
  PIZ (lossless).

:RLE:             
  RLE (lossless).

:ZIPS:            
  ZIPS (lossless).

:B44:             
  B44 (lossy).

:B44A:            
  B44A (lossy).

:DWAA:            
  DWAA (lossy).

:DWAB:            
  DWAB (lossy).

.. _rna-enum-exr-codec-items:

"""

import typing
