"""


Node Compare Operation Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:LESS_THAN:       
  Less Than.

  True when the first input is smaller than second input.

:LESS_EQUAL:      
  Less Than or Equal.

  True when the first input is smaller than the second input or equal.

:GREATER_THAN:    
  Greater Than.

  True when the first input is greater than the second input.

:GREATER_EQUAL:   
  Greater Than or Equal.

  True when the first input is greater than the second input or equal.

:EQUAL:           
  Equal.

  True when both inputs are approximately equal.

:NOT_EQUAL:       
  Not Equal.

  True when both inputs are not approximately equal.

:BRIGHTER:        
  Brighter.

  True when the first input is brighter.

:DARKER:          
  Darker.

  True when the first input is darker.

.. _rna-enum-node-compare-operation-items:

"""

import typing
