"""


Brush Weight Tool Items
^^^^^^^^^^^^^^^^^^^^^^^

:DRAW:            
  Draw.

:BLUR:            
  Blur.

:AVERAGE:         
  Average.

:SMEAR:           
  Smear.

.. _rna-enum-brush-weight-tool-items:

"""

import typing
