"""


Subdivision Uv Smooth Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^

:NONE:            
  None.

  UVs are not smoothed, boundaries are kept sharp.

:PRESERVE_CORNERS:
  Keep Corners.

  UVs are smoothed, corners on discontinuous boundary are kept sharp.

:PRESERVE_CORNERS_AND_JUNCTIONS:
  Keep Corners, Junctions.

  UVs are smoothed, corners on discontinuous boundary and junctions of 3 or more regions are kept sharp.

:PRESERVE_CORNERS_JUNCTIONS_AND_CONCAVE:
  Keep Corners, Junctions, Concave.

  UVs are smoothed, corners on discontinuous boundary, junctions of 3 or more regions and darts and concave corners are kept sharp.

:PRESERVE_BOUNDARIES:
  Keep Boundaries.

  UVs are smoothed, boundaries are kept sharp.

:SMOOTH_ALL:      
  All.

  UVs and boundaries are smoothed.

.. _rna-enum-subdivision-uv-smooth-items:

"""

import typing
