"""


Keyframe Paste Merge Items
^^^^^^^^^^^^^^^^^^^^^^^^^^

:MIX:             
  Mix.

  Overlay existing with new keys.

:OVER_ALL:        
  Overwrite All.

  Replace all keys.

:OVER_RANGE:      
  Overwrite Range.

  Overwrite keys in pasted range.

:OVER_RANGE_ALL:  
  Overwrite Entire Range.

  Overwrite keys in pasted range, using the range of all copied keys.

.. _rna-enum-keyframe-paste-merge-items:

"""

import typing
