"""


Snap Source Items
^^^^^^^^^^^^^^^^^

:CLOSEST:         
  Closest.

  Snap closest point onto target.

:CENTER:          
  Center.

  Snap transformation center onto target.

:MEDIAN:          
  Median.

  Snap median onto target.

:ACTIVE:          
  Active.

  Snap active onto target.

.. _rna-enum-snap-source-items:

"""

import typing
