"""


Material Operators
******************

:func:`copy`

:func:`new`

:func:`paste`

"""

import typing

def copy() -> None:

  """

  Copy the material settings and nodes

  """

  ...

def new() -> None:

  """

  Add a new material

  """

  ...

def paste() -> None:

  """

  Paste the material settings and nodes

  """

  ...
