"""


Driver Target Rotation Mode Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:AUTO:            
  Auto Euler.

  Euler using the rotation order of the target.

:XYZ:             
  XYZ Euler.

  Euler using the XYZ rotation order.

:XZY:             
  XZY Euler.

  Euler using the XZY rotation order.

:YXZ:             
  YXZ Euler.

  Euler using the YXZ rotation order.

:YZX:             
  YZX Euler.

  Euler using the YZX rotation order.

:ZXY:             
  ZXY Euler.

  Euler using the ZXY rotation order.

:ZYX:             
  ZYX Euler.

  Euler using the ZYX rotation order.

:QUATERNION:      
  Quaternion.

  Quaternion rotation.

:SWING_TWIST_X:   
  Swing and X Twist.

  Decompose into a swing rotation to aim the X axis, followed by twist around it.

:SWING_TWIST_Y:   
  Swing and Y Twist.

  Decompose into a swing rotation to aim the Y axis, followed by twist around it.

:SWING_TWIST_Z:   
  Swing and Z Twist.

  Decompose into a swing rotation to aim the Z axis, followed by twist around it.

.. _rna-enum-driver-target-rotation-mode-items:

"""

import typing
