"""


Property Subtype Number Array Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:COLOR:           
  Color.

:TRANSLATION:     
  Translation.

:DIRECTION:       
  Direction.

:VELOCITY:        
  Velocity.

:ACCELERATION:    
  Acceleration.

:MATRIX:          
  Matrix.

:EULER:           
  Euler Angles.

:QUATERNION:      
  Quaternion.

:AXISANGLE:       
  Axis-Angle.

:XYZ:             
  XYZ.

:XYZ_LENGTH:      
  XYZ Length.

:COLOR_GAMMA:     
  Color.

:COORDINATES:     
  Coordinates.

:LAYER:           
  Layer.

:LAYER_MEMBER:    
  Layer Member.

:NONE:            
  None.

.. _rna-enum-property-subtype-number-array-items:

"""

import typing
