"""


Curve Fit Method Items
^^^^^^^^^^^^^^^^^^^^^^

:REFIT:           
  Refit.

  Incrementally refit the curve (high quality).

:SPLIT:           
  Split.

  Split the curve until the tolerance is met (fast).

.. _rna-enum-curve-fit-method-items:

"""

import typing
