"""


Bake Margin Type Items
^^^^^^^^^^^^^^^^^^^^^^

:ADJACENT_FACES:  
  Adjacent Faces.

  Use pixels from adjacent faces across UV seams.

:EXTEND:          
  Extend.

  Extend border pixels outwards.

.. _rna-enum-bake-margin-type-items:

"""

import typing
