"""


Space Graph Mode Items
^^^^^^^^^^^^^^^^^^^^^^

:FCURVES:         
  Graph Editor.

  Edit animation/keyframes displayed as 2D curves.

:DRIVERS:         
  Drivers.

  Edit drivers.

.. _rna-enum-space-graph-mode-items:

"""

import typing
