"""


Keyblock Type Items
^^^^^^^^^^^^^^^^^^^

:KEY_LINEAR:      
  Linear.

:KEY_CARDINAL:    
  Cardinal.

:KEY_CATMULL_ROM: 
  Catmull-Rom.

:KEY_BSPLINE:     
  BSpline.

.. _rna-enum-keyblock-type-items:

"""

import typing
