"""


Brush Curves Sculpt Tool Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:COMB:            
  Comb Curves.

:DELETE:          
  Delete Curves.

:SNAKE_HOOK:      
  Curves Snake Hook.

:ADD:             
  Add Curves.

:GROW_SHRINK:     
  Grow / Shrink Curves.

:SELECTION_PAINT: 
  Paint Selection.

:PINCH:           
  Pinch Curves.

:SMOOTH:          
  Smooth Curves.

:PUFF:            
  Puff Curves.

:DENSITY:         
  Density Curves.

:SLIDE:           
  Slide Curves.

.. _rna-enum-brush-curves-sculpt-tool-items:

"""

import typing
