"""


Dt Method Vertex Items
^^^^^^^^^^^^^^^^^^^^^^

:TOPOLOGY:        
  Topology.

  Copy from identical topology meshes.

:NEAREST:         
  Nearest Vertex.

  Copy from closest vertex.

:EDGE_NEAREST:    
  Nearest Edge Vertex.

  Copy from closest vertex of closest edge.

:EDGEINTERP_NEAREST:
  Nearest Edge Interpolated.

  Copy from interpolated values of vertices from closest point on closest edge.

:POLY_NEAREST:    
  Nearest Face Vertex.

  Copy from closest vertex of closest face.

:POLYINTERP_NEAREST:
  Nearest Face Interpolated.

  Copy from interpolated values of vertices from closest point on closest face.

:POLYINTERP_VNORPROJ:
  Projected Face Interpolated.

  Copy from interpolated values of vertices from point on closest face hit by normal-projection.

.. _rna-enum-dt-method-vertex-items:

"""

import typing
