"""


Normal Space Items
^^^^^^^^^^^^^^^^^^

:OBJECT:          
  Object.

  Bake the normals in object space.

:TANGENT:         
  Tangent.

  Bake the normals in tangent space.

.. _rna-enum-normal-space-items:

"""

import typing
