"""


Color Sets Items
^^^^^^^^^^^^^^^^

:DEFAULT:         
  Default Colors.

:THEME01:         
  01 - Theme Color Set.

:THEME02:         
  02 - Theme Color Set.

:THEME03:         
  03 - Theme Color Set.

:THEME04:         
  04 - Theme Color Set.

:THEME05:         
  05 - Theme Color Set.

:THEME06:         
  06 - Theme Color Set.

:THEME07:         
  07 - Theme Color Set.

:THEME08:         
  08 - Theme Color Set.

:THEME09:         
  09 - Theme Color Set.

:THEME10:         
  10 - Theme Color Set.

:THEME11:         
  11 - Theme Color Set.

:THEME12:         
  12 - Theme Color Set.

:THEME13:         
  13 - Theme Color Set.

:THEME14:         
  14 - Theme Color Set.

:THEME15:         
  15 - Theme Color Set.

:THEME16:         
  16 - Theme Color Set.

:THEME17:         
  17 - Theme Color Set.

:THEME18:         
  18 - Theme Color Set.

:THEME19:         
  19 - Theme Color Set.

:THEME20:         
  20 - Theme Color Set.

:CUSTOM:          
  Custom Color Set.

.. _rna-enum-color-sets-items:

"""

import typing
