"""


Render Pass Type Items
^^^^^^^^^^^^^^^^^^^^^^

:COMBINED:        
  Combined.

:Z:               
:SHADOW:          
  Shadow.

:AO:              
  Ambient Occlusion.

:POSITION:        
  Position.

:NORMAL:          
  Normal.

:VECTOR:          
  Vector.

:OBJECT_INDEX:    
  Object Index.

:UV:              
  UV.

:MIST:            
  Mist.

:EMIT:            
  Emit.

:ENVIRONMENT:     
  Environment.

:MATERIAL_INDEX:  
  Material Index.

:DIFFUSE_DIRECT:  
  Diffuse Direct.

:DIFFUSE_INDIRECT:
  Diffuse Indirect.

:DIFFUSE_COLOR:   
  Diffuse Color.

:GLOSSY_DIRECT:   
  Glossy Direct.

:GLOSSY_INDIRECT: 
  Glossy Indirect.

:GLOSSY_COLOR:    
  Glossy Color.

:TRANSMISSION_DIRECT:
  Transmission Direct.

:TRANSMISSION_INDIRECT:
  Transmission Indirect.

:TRANSMISSION_COLOR:
  Transmission Color.

:SUBSURFACE_DIRECT:
  Subsurface Direct.

:SUBSURFACE_INDIRECT:
  Subsurface Indirect.

:SUBSURFACE_COLOR:
  Subsurface Color.

.. _rna-enum-render-pass-type-items:

"""

import typing
