"""


Brush Uv Sculpt Tool Items
^^^^^^^^^^^^^^^^^^^^^^^^^^

:GRAB:            
  Grab.

  Grab UVs.

:RELAX:           
  Relax.

  Relax UVs.

:PINCH:           
  Pinch.

  Pinch UVs.

.. _rna-enum-brush-uv-sculpt-tool-items:

"""

import typing
