"""


Motionpath Range Items
^^^^^^^^^^^^^^^^^^^^^^

:KEYS_ALL:        
  All Keys.

  From the first keyframe to the last.

:KEYS_SELECTED:   
  Selected Keys.

  From the first selected keyframe to the last.

:SCENE:           
  Scene Frame Range.

  The entire Scene / Preview range.

:MANUAL:          
  Manual Range.

  Manually determined frame range.

.. _rna-enum-motionpath-range-items:

"""

import typing
