"""


Event Type Mask Items
^^^^^^^^^^^^^^^^^^^^^

:KEYBOARD_MODIFIER:
  Keyboard Modifier.

:KEYBOARD:        
  Keyboard.

:MOUSE_WHEEL:     
  Mouse Wheel.

:MOUSE_GESTURE:   
  Mouse Gesture.

:MOUSE_BUTTON:    
  Mouse Button.

:MOUSE:           
  Mouse.

:NDOF:            
  NDOF.

:ACTIONZONE:      
  Action Zone.

.. _rna-enum-event-type-mask-items:

"""

import typing
