"""


Safe Areas Operators
********************

:func:`preset_add`

"""

import typing

def preset_add(name: str = '', remove_name: bool = False, remove_active: bool = False) -> None:

  """

  Add or remove a Safe Areas Preset

  """

  ...
