"""


Property Override Flag Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:LIBRARY_OVERRIDABLE:
  Library Overridable.

  Make that property editable in library overrides of linked data-blocks.

.. _rna-enum-property-override-flag-items:

"""

import typing
