"""


Light Type Items
^^^^^^^^^^^^^^^^

:POINT:           
  Point.

  Omnidirectional point light source.

:SUN:             
  Sun.

  Constant direction parallel ray light source.

:SPOT:            
  Spot.

  Directional cone light source.

:AREA:            
  Area.

  Directional area light source.

.. _rna-enum-light-type-items:

"""

import typing
