"""


Snap Node Element Items
^^^^^^^^^^^^^^^^^^^^^^^

:GRID:            
  Grid.

  Snap to grid.

:NODE_X:          
  Node X.

  Snap to left/right node border.

:NODE_Y:          
  Node Y.

  Snap to top/bottom node border.

:NODE_XY:         
  Node X / Y.

  Snap to any node border.

.. _rna-enum-snap-node-element-items:

"""

import typing
