"""


Unpack Method Items
^^^^^^^^^^^^^^^^^^^

:REMOVE:          
  Remove Pack.

:USE_LOCAL:       
  Use Local File.

:WRITE_LOCAL:     
  Write Local File (overwrite existing).

:USE_ORIGINAL:    
  Use Original File.

:WRITE_ORIGINAL:  
  Write Original File (overwrite existing).

.. _rna-enum-unpack-method-items:

"""

import typing
