"""


Image Color Depth Items
^^^^^^^^^^^^^^^^^^^^^^^

:8:               
  8-bit color channels.

:10:              
  10-bit color channels.

:12:              
  12-bit color channels.

:16:              
  16-bit color channels.

:32:              
  32-bit color channels.

.. _rna-enum-image-color-depth-items:

"""

import typing
