"""


Stereo3D Display Items
^^^^^^^^^^^^^^^^^^^^^^

:ANAGLYPH:        
  Anaglyph.

  Render views for left and right eyes as two differently filtered colors in a single image (anaglyph glasses are required).

:INTERLACE:       
  Interlace.

  Render views for left and right eyes interlaced in a single image (3D-ready monitor is required).

:TIMESEQUENTIAL:  
  Time Sequential.

  Render alternate eyes (also known as page flip, quad buffer support in the graphic card is required).

:SIDEBYSIDE:      
  Side-by-Side.

  Render views for left and right eyes side-by-side.

:TOPBOTTOM:       
  Top-Bottom.

  Render views for left and right eyes one above another.

.. _rna-enum-stereo3d-display-items:

"""

import typing
