"""


Property Subtype Items
^^^^^^^^^^^^^^^^^^^^^^

:NONE:            
  None.

:FILE_PATH:       
  File Path.

:DIR_PATH:        
  Directory Path.

:FILE_NAME:       
  File Name.

:BYTE_STRING:     
  Byte String.

:PASSWORD:        
  Password.

  A string that is displayed hidden ('********').

:PIXEL:           
  Pixel.

:UNSIGNED:        
  Unsigned.

:PERCENTAGE:      
  Percentage.

:FACTOR:          
  Factor.

:ANGLE:           
  Angle.

:TIME:            
  Time (Scene Relative).

  Time specified in frames, converted to seconds based on scene frame rate.

:TIME_ABSOLUTE:   
  Time (Absolute).

  Time specified in seconds, independent of the scene.

:DISTANCE:        
  Distance.

:DISTANCE_CAMERA: 
  Camera Distance.

:POWER:           
  Power.

:TEMPERATURE:     
  Temperature.

:COLOR:           
  Color.

:TRANSLATION:     
  Translation.

:DIRECTION:       
  Direction.

:VELOCITY:        
  Velocity.

:ACCELERATION:    
  Acceleration.

:MATRIX:          
  Matrix.

:EULER:           
  Euler Angles.

:QUATERNION:      
  Quaternion.

:AXISANGLE:       
  Axis-Angle.

:XYZ:             
  XYZ.

:XYZ_LENGTH:      
  XYZ Length.

:COLOR_GAMMA:     
  Color.

:COORDINATES:     
  Coordinates.

:LAYER:           
  Layer.

:LAYER_MEMBER:    
  Layer Member.

.. _rna-enum-property-subtype-items:

"""

import typing
