"""


Property String Search Flag Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:SORT:            
  Sort Search Results.

:SUGGESTION:      
  Suggestion.

  Search results are suggestions (other values may be entered).

.. _rna-enum-property-string-search-flag-items:

"""

import typing
